@@ -500,7 +500,7 @@ def process_folder_w_mm_files(folder_path: Path, cli: bool = False, options: dic
             continue
         # Ignore non-video and non-image files
         # TODO Add here any video or image extensions we want to support
-        if (child.suffix not in [".mp4", ".mov", ".avi", ".mkv", ".ts"]) and (
+        if (child.suffix not in [".mp4", ".mov", ".avi", ".mkv", ".ts", ".y4m"]) and (
                 child.suffix not in [".png", ".jpg", ".jpeg", ".bmp", ".gif"]):
             logger.info(f"Not a multimedia file ({str(child)}), skipping")
             continue
